==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/account_history.php <==
<?php
/*
  $Id: account_history.php,v 1.2 2005/08/19 09:48:11 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  require('includes/application_top.php');

  if (!tep_session_is_registered('customer_id')) {
    $navigation->set_snapshot();
    tep_redirect(tep_href_link(FILENAME_LOGIN, '', 'SSL'));
  }

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_ACCOUNT_HISTORY);

  $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_ACCOUNT, '', 'SSL'));
  $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_ACCOUNT_HISTORY, '', 'SSL'));
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
<link rel="stylesheet" type="text/css" href="general.css">
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ACCOUNT_HISTORY, 0, strrpos(FILENAME_ACCOUNT_HISTORY, '.'));?>.css">
</head>
<body>
<div id="bodyWrapper">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->
<!-- body //-->
<table id="contents">
  <tr>
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
<!-- body_text //-->
    <td id="mainContents">
      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
<?php
  $history_query_raw = "select o.orders_id, o.date_purchased, o.delivery_name, ot.text as order_total, s.orders_status_name from " . TABLE_ORDERS . " o left join " . TABLE_ORDERS_TOTAL . " ot on (o.orders_id = ot.orders_id) left join " . TABLE_ORDERS_STATUS . " s on (o.orders_status = s.orders_status_id and s.language_id = '" . $languages_id . "') where o.customers_id = '" . $customer_id . "' and ot.class = 'ot_total' order by orders_id DESC";
  $history_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_ORDER_HISTORY, $history_query_raw, $history_numrows);
  $history_query = tep_db_query($history_query_raw);

  if (tep_db_num_rows($history_query)) {
    echo '<div id="accountHistory">' . "\n";
    while ($history = tep_db_fetch_array($history_query)) {
      $products_query = tep_db_query("select count(*) as count from " . TABLE_ORDERS_PRODUCTS . " where orders_id = '" . $history['orders_id'] . "'");
      $products = tep_db_fetch_array($products_query);

      echo '<div class="accountHistoryList">' . "\n";
      if (KN_CFG_USE_ORDER_HISTORY == 'true') {
        $contentbox_header = '<table class="contentBoxHeader">' . "\n" .
                                    '  <tr>' . "\n" .
                                    '    <td class="ordersID"><span class="tableHeading">' . TEXT_ORDER_NUMBER . '</span> ' . $history['orders_id'] . '</td>' . "\n" .
                                    '    <td class="ordersStatus"><span class="tableHeading">' . TEXT_ORDER_STATUS . '</span> ' . $history['orders_status_name'] . '</td>' . "\n" .
                                    '  </tr>' . "\n" .
                                    '</table>' . "\n";
      } else {
        $contentbox_header = '<table class="contentBoxHeader">' . "\n" .
                                    '  <tr>' . "\n" .
                                    '    <td class="ordersID"><span class="tableHeading">' . TEXT_ORDER_NUMBER . '</span> ' . $history['orders_id'] . '</td>' . "\n" .
                                    '  </tr>' . "\n" .
                                    '</table>' . "\n";
      }
      $orders_list = '<table class="contentBoxContent">' . "\n" .
                        '  <tr>' . "\n" .
                        '    <td class="accountHistoryListCol01"><span class="tableHeading">' . TEXT_ORDER_DATE . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol02">' . tep_date_long($history['date_purchased']) . '</td>' . "\n" . 
                        '    <td class="accountHistoryListCol03"><span class="tableHeading">' . TEXT_ORDER_PRODUCTS . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol04">' . $products['count'] . '</td>' . "\n" .
                        '    <td class="accountHistoryListCol05" rowspan="2"><a href="' . tep_href_link(FILENAME_ACCOUNT_HISTORY_INFO, 'page=' . $HTTP_GET_VARS['page'] . '&order_id=' . $history['orders_id'], 'SSL') . '">' . TEXT_VIEW_ORDER . '</a></td>' . "\n" .
                        '  </tr>' . "\n" .
                        '  <tr>' . "\n" .
                        '    <td class="accountHistoryListCol01"><span class="tableHeading">' . TEXT_ORDER_SHIPPED_TO . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol02">' . tep_output_string_protected($history['delivery_name']) . '</td>' . "\n" . 
                        '    <td class="accountHistoryListCol03"><span class="tableHeading">' . TEXT_ORDER_COST . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol04">' . strip_tags($history['order_total']) . '</td>' . "\n" .
                        '  </tr>' . "\n" .
                        '</table>' . "\n";
      echo $contentbox_header;
      echo $orders_list;
      echo "</div>\n";
    }
    echo '<table class="listFooter">' . "\n";
    echo '  <tr>' . "\n";
    echo '     <td class="listCount">' . $history_split->display_count($history_numrows, MAX_DISPLAY_ORDER_HISTORY, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_ORDERS) . "</td>\n";
    echo '     <td class="listPrevNext">' . TEXT_RESULT_PAGE;
    $history_split->display_links($history_numrows, MAX_DISPLAY_ORDER_HISTORY, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y')));
    echo "</td>\n";
    echo "  </tr>\n";
    echo "</table>\n";
    echo "</div>\n";
  } else {
    echo '<div class="noData">' . TEXT_NO_PURCHASES . "</div>\n";
  }
?>
      <table>
        <tr class="buttonLine">
          <td class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_ACCOUNT, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></td>
        </tr>
      </table>
    </td>
<!-- body_text_eof //-->
<!-- right_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- right_navigation_eof //-->
  </tr>
</table>
<!-- body_eof //-->
<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

==> koshoten.net-2.1.6.tar.gz: koshoten-net/catalog/account_history.php <==
<?php
/*
  $Id: account_history.php,v 1.3 2006/03/23 02:12:25 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  require('includes/application_top.php');

  if (defined("KN_CFG_ALLOW_CHECKOUT") && (KN_CFG_ALLOW_CHECKOUT == "false")) {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }

  if (!tep_session_is_registered('customer_id')) {
    $navigation->set_snapshot();
    tep_redirect(tep_href_link(FILENAME_LOGIN, '', 'SSL'));
  }

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_ACCOUNT_HISTORY);

  $breadcrumb->add(NAVBAR_TITLE_1, tep_href_link(FILENAME_ACCOUNT, '', 'SSL'));
  $breadcrumb->add(NAVBAR_TITLE_2, tep_href_link(FILENAME_ACCOUNT_HISTORY, '', 'SSL'));
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
<link rel="stylesheet" type="text/css" href="general.css">
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_ACCOUNT_HISTORY, 0, strrpos(FILENAME_ACCOUNT_HISTORY, '.'));?>.css">
</head>
<body>
<div id="bodyWrapper">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->
<!-- body //-->
<table id="contents">
  <tr>
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
<!-- body_text //-->
    <td id="mainContents">
      <h1 class="pageHeading"><?php echo HEADING_TITLE; ?></h1>
<?php
  $history_query_raw = "select o.orders_id, o.date_purchased, o.delivery_name, ot.text as order_total, s.orders_status_name from " . TABLE_ORDERS . " o left join " . TABLE_ORDERS_TOTAL . " ot on (o.orders_id = ot.orders_id) left join " . TABLE_ORDERS_STATUS . " s on (o.orders_status = s.orders_status_id and s.language_id = '" . $languages_id . "') where o.customers_id = '" . $customer_id . "' and ot.class = 'ot_total' order by orders_id DESC";
  $history_split = new splitPageResults($HTTP_GET_VARS['page'], MAX_DISPLAY_ORDER_HISTORY, $history_query_raw, $history_numrows);
  $history_query = tep_db_query($history_query_raw);

  if (tep_db_num_rows($history_query)) {
    echo '<div id="accountHistory">' . "\n";
    while ($history = tep_db_fetch_array($history_query)) {
      $products_query = tep_db_query("select count(*) as count from " . TABLE_ORDERS_PRODUCTS . " where orders_id = '" . $history['orders_id'] . "'");
      $products = tep_db_fetch_array($products_query);

      echo '<div class="accountHistoryList">' . "\n";
      if (KN_CFG_USE_ORDER_HISTORY == 'true') {
        $contentbox_header = '<table class="contentBoxHeader">' . "\n" .
                                    '  <tr>' . "\n" .
                                    '    <td class="ordersID"><span class="tableHeading">' . TEXT_ORDER_NUMBER . '</span> ' . $history['orders_id'] . '</td>' . "\n" .
                                    '    <td class="ordersStatus"><span class="tableHeading">' . TEXT_ORDER_STATUS . '</span> ' . $history['orders_status_name'] . '</td>' . "\n" .
                                    '  </tr>' . "\n" .
                                    '</table>' . "\n";
      } else {
        $contentbox_header = '<table class="contentBoxHeader">' . "\n" .
                                    '  <tr>' . "\n" .
                                    '    <td class="ordersID"><span class="tableHeading">' . TEXT_ORDER_NUMBER . '</span> ' . $history['orders_id'] . '</td>' . "\n" .
                                    '  </tr>' . "\n" .
                                    '</table>' . "\n";
      }
      $orders_list = '<table class="contentBoxContent">' . "\n" .
                        '  <tr>' . "\n" .
                        '    <td class="accountHistoryListCol01"><span class="tableHeading">' . TEXT_ORDER_DATE . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol02">' . tep_date_long($history['date_purchased']) . '</td>' . "\n" . 
                        '    <td class="accountHistoryListCol03"><span class="tableHeading">' . TEXT_ORDER_PRODUCTS . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol04">' . $products['count'] . '</td>' . "\n" .
                        '    <td class="accountHistoryListCol05" rowspan="2"><a href="' . tep_href_link(FILENAME_ACCOUNT_HISTORY_INFO, 'page=' . $HTTP_GET_VARS['page'] . '&order_id=' . $history['orders_id'], 'SSL') . '">' . TEXT_VIEW_ORDER . '</a></td>' . "\n" .
                        '  </tr>' . "\n" .
                        '  <tr>' . "\n" .
                        '    <td class="accountHistoryListCol01"><span class="tableHeading">' . TEXT_ORDER_SHIPPED_TO . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol02">' . tep_output_string_protected($history['delivery_name']) . '</td>' . "\n" . 
                        '    <td class="accountHistoryListCol03"><span class="tableHeading">' . TEXT_ORDER_COST . '</span></td>' . "\n" . 
                        '    <td class="accountHistoryListCol04">' . strip_tags($history['order_total']) . '</td>' . "\n" .
                        '  </tr>' . "\n" .
                        '</table>' . "\n";
      echo $contentbox_header;
      echo $orders_list;
      echo "</div>\n";
    }
    echo '<table class="listFooter">' . "\n";
    echo '  <tr>' . "\n";
    echo '     <td class="listCount">' . $history_split->display_count($history_numrows, MAX_DISPLAY_ORDER_HISTORY, $HTTP_GET_VARS['page'], TEXT_DISPLAY_NUMBER_OF_ORDERS) . "</td>\n";
    echo '     <td class="listPrevNext">' . TEXT_RESULT_PAGE;
    $history_split->display_links($history_numrows, MAX_DISPLAY_ORDER_HISTORY, MAX_DISPLAY_PAGE_LINKS, $HTTP_GET_VARS['page'], tep_get_all_get_params(array('page', 'info', 'x', 'y')));
    echo "</td>\n";
    echo "  </tr>\n";
    echo "</table>\n";
    echo "</div>\n";
  } else {
    echo '<div class="noData">' . TEXT_NO_PURCHASES . "</div>\n";
  }
?>
      <table>
        <tr class="buttonLine">
          <td class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_ACCOUNT, '', 'SSL') . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></td>
        </tr>
      </table>
    </td>
<!-- body_text_eof //-->
<!-- right_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- right_navigation_eof //-->
  </tr>
</table>
<!-- body_eof //-->
<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
